@@ -1,5 +1,5 @@
 /*
-*  Copyright (C) 2004, 2011-2012 Samuel Thibault <samuel.thibault@ens-lyon.org>
+*  Copyright (C) 2004, 2011-2012, 2017 Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -356,7 +356,34 @@ enum {
 };
 
 unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec, uint64_t stamp, unsigned long code);
-int fut_flush( char* filename, void* next_slot, int record_flush_events );
+int fut_flush( char* filename, void *first_slot, void* next_slot, int record_flush_events );
 void __fut_reset_pointers();
+unsigned int fut_nallocated;
+
+#define i386_sync() __asm__ __volatile__("lock; addl $0,0(%%esp)" ::: "memory")
+#define x86_64_sync() __asm__ __volatile__("lock; addl $0,0(%%rsp)" ::: "memory")
+#define ppc_sync() __asm__ __volatile__("sync" ::: "memory")
+
+#if defined(__i386__)
+#define mb() i386_sync()
+#define rmb() i386_sync()
+#define wmb() i386_sync()
+#elif defined(__KNC__) || defined(__KNF__)
+#define mb() x86_64_sync()
+#define rmb() mb()
+#define wmb() mb()
+#elif defined(__x86_64__)
+#define mb() x86_64_sync()
+#define rmb() __asm__ __volatile__("lfence" ::: "memory")
+#define wmb() __asm__ __volatile__("sfence" ::: "memory")
+#elif defined(__ppc__) || defined(__ppc64__)
+#define mb() ppc_sync()
+#define rmb() ppc_sync()
+#define wmb() ppc_sync()
+#else
+#define mb() __sync_synchronize()
+#define rmb() __sync_synchronize()
+#define wmb() __sync_synchronize()
+#endif
 
 #endif /* __FXT_INTERNAL_H */
