@@ -69,8 +69,14 @@ int fxt_get_cpu_info( fxt_t fxt )
 				{/* end of the file, did we find any cpus? */
 				fclose(fptr);
 				if( fxt->infos.ncpus <= 0 )
+					{
 					/* no, end of file was premature */
 					fprintf(stderr, "end of file on %s\n", PROC_FILE);
+					fprintf(stderr, "Assuming 1 1GHz proc\n");
+					fxt->infos.mhz = malloc(sizeof(*fxt->infos.mhz));
+					fxt->infos.mhz[0] = 1000;
+					return fxt->infos.ncpus = 1;
+					}
 				else
 					/* yes, normal return with that number */
 					return fxt->infos.ncpus;
